summaryrefslogtreecommitdiffstats
path: root/libdvdnav/dvdnav.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
commitb0e912c8b3d02a518fedda28c3180eb4794a7520 (patch)
tree07d344862562fab58cbe2df39d13d16f2e4d2bea /libdvdnav/dvdnav.h
parent4d695ec81fe4d4335ee82c7a9346ad9c9e144ecc (diff)
downloadk9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.tar.gz
k9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.zip
TQt4 convert k9copy
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1233843 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libdvdnav/dvdnav.h')
-rw-r--r--libdvdnav/dvdnav.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libdvdnav/dvdnav.h b/libdvdnav/dvdnav.h
index 1e39d0b..b8618d9 100644
--- a/libdvdnav/dvdnav.h
+++ b/libdvdnav/dvdnav.h
@@ -52,7 +52,7 @@ extern "C" {
*/
typedef struct dvdnav_s dvdnav_t;
-/* Status as reported by most of libdvdnav's functions */
+/* tqStatus as reported by most of libdvdnav's functions */
typedef int32_t dvdnav_status_t;
/*
@@ -120,22 +120,22 @@ int64_t dvdnav_convert_time(dvd_time_t *time);
*/
/*
* Sets the region mask (bit 0 set implies region 1, bit 1 set implies
* region 2, etc) of the virtual machine. Generally you will only need to set
* this if you are playing RCE discs which query the virtual machine as to its
* region setting.
*
* This has _nothing_ to do with the region setting of the DVD drive.
*/
-dvdnav_status_t dvdnav_set_region_mask(dvdnav_t *self, int32_t region_mask);
+dvdnav_status_t dvdnav_set_region_tqmask(dvdnav_t *self, int32_t region_tqmask);
/*
* Returns the region mask (bit 0 set implies region 1, bit 1 set implies
* region 2, etc) of the virtual machine.
*
* This has _nothing_ to do with the region setting of the DVD drive.
*/
-dvdnav_status_t dvdnav_get_region_mask(dvdnav_t *self, int32_t *region_mask);
+dvdnav_status_t dvdnav_get_region_tqmask(dvdnav_t *self, int32_t *region_tqmask);
/*
* Specify whether read-ahead caching should be used. You may not want this if your
@@ -120,22 +120,22 @@ int64_t dvdnav_convert_time(dvd_time_t *time);
*/
/*
- * Sets the region mask (bit 0 set implies region 1, bit 1 set implies
+ * Sets the region tqmask (bit 0 set implies region 1, bit 1 set implies
* region 2, etc) of the virtual machine. Generally you will only need to set
* this if you are playing RCE discs which query the virtual machine as to its
@@ -120,22 +120,22 @@ int64_t dvdnav_convert_time(dvd_time_t *time);
/*
- * Returns the region mask (bit 0 set implies region 1, bit 1 set implies
+ * Returns the region tqmask (bit 0 set implies region 1, bit 1 set implies
* region 2, etc) of the virtual machine.
*